import React,{Component} from "react";
import { View,Image } from '@tarojs/components'
import Taro, { getCurrentInstance } from "@tarojs/taro";
import {AtButton, AtIcon, AtTextarea} from 'taro-ui'
import {examinePublicRelease} from '../../utils/servers/servers';
import './index.less';

import 'taro-ui/dist/style/components/icon.scss';
import 'taro-ui/dist/style/components/textarea.scss'

import Rejected from '../../image/rejected.png';
import Passed from '../../image/passed.png';
import Reviewed from '../../image/reviewed.png';

class EgressDetails extends Component{

  $instance = getCurrentInstance()

  constructor(props) {
    super(props);
    this.state={
      dtails:{},
      remarks:''
    }
    this.examinePublicRelease= this.examinePublicRelease.bind(this);
  }

  componentDidShow() {
    this.setState({
      dtails:JSON.parse(this.$instance.router.params.dtails),
      remarks:JSON.parse(this.$instance.router.params.dtails).remarks
    })
  }

  examinePublicRelease(status){
    if(!this.state.remarks){
      Taro.showToast({title:'请填写审批意见',icon:'none'})
      return;
    }
    examinePublicRelease({
      status,
      remarks:this.state.remarks,
      id:this.state.dtails.id
    }).then(v=>{
      if(v.error.length === 0){
        Taro.showToast({title:status===0?'驳回成功':'通过成功',icon:'none'});
        this.state.dtails.status=status;
        this.setState({
          dtails:this.state.dtails
        })
      }else{
        Taro.showToast({title:v.error[0].message,icon:'none'})
      }
    }).catch(()=>{
      Taro.showToast({title:'系统错误,请稍后再试',icon:'none'})
    })
  }

  render() {
    const {dtails} = this.state;
    //aname: "营销员"
    // createTimes: "2021-06-07 14:40:46"
    // id: "11"
    // nickname: "1111111111"
    // releaseEnds: "2021-06-13 15:40:00"
    // releaseStarts: "2021-06-07 14:40:00"
    // status: 1
    // userName: "肯德基(西客站餐厅)"
    return (
      <View className='egressDetails'>
        <View className='titleContent'>
          <View className='title'>{dtails.aname}提交的外出申请</View>
          <View className='address'>
            <AtIcon value='map-pin' size='15' color='#767272'/>
            公出企业:{dtails.nickname}
          </View>
          <View className='state' style={{
            color:dtails.status === 0 ? '#f31212' :
              dtails.status === 1 ? '#1d4fea' :
                dtails.status === 2 ? '#767272' : ''
          }}>
            {
              dtails.status === 0 ? '驳回' :
                dtails.status === 1 ? '发起' :
                  dtails.status === 2 ? '通过' : ''
            }
          </View>
          <Image src={
            dtails.status === 0 ? Rejected :
              dtails.status === 1 ? Reviewed :
                dtails.status === 2 ? Passed : ''} className='startIcon'/>
        </View>
        <View className='valueContent'>
          {/*<View className='item'>*/}
          {/*  <View className='title'>外出编号</View>*/}
          {/*  <View className='value'>20212584646465495462</View>*/}
          {/*</View>*/}
          {/*<View className='item'>*/}
          {/*  <View className='title'>企业类型</View>*/}
          {/*  <View className='value'>稀有企业</View>*/}
          {/*</View>*/}
          {/*<View className='item'>*/}
          {/*  <View className='title'>审核人</View>*/}
          {/*  <View className='value'>营销经理</View>*/}
          {/*</View>*/}
          <View className='item'>
            <View className='title'>公出地点:</View>
            <View className='value'>{dtails.userName}</View>
            <View className='timeContent'>
              <View className='time'>
                <View className='num'>外出1.5小时</View>
                <View className='journal'>明细</View>
              </View>
              <View className='timeAxis'>
                <View className='startTime'>
                  <View className='circle'/>
                  {dtails.releaseStarts}
                </View>
                <View className='axis'/>
                <View className='endTime'>
                  <View className='circle'/>
                  {dtails.releaseEnds}
                </View>
              </View>
            </View>
          </View>
          <View className='item'>
            <View className='title'>申请时间</View>
            <View className='value'>{dtails.createTimes}</View>
          </View>
          <View className='item'>
            <View className='title'>外出原因</View>
            <View className='value'>振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权振权</View>
          </View>
          {
            this.$instance.router.params.type === '1' ?
              <View className='item'>
                <View className='title'>填写审批意见</View>
                <AtTextarea
                  value={this.state.remarks}
                  onChange={(value)=>{
                    this.setState({
                      remarks:value
                    })
                  }}
                  maxLength={200}
                  placeholder='请填写审批意见'
                />
              </View> : null
          }
          {
            this.$instance.router.params.type === '1' ?
              <View className='operation'>
                <AtButton type='secondary' circle loading={this.state.loading} onClick={()=>{
                  this.examinePublicRelease(0);
                }}>
                  驳回
                </AtButton>
                <AtButton type='primary' loading={this.state.loading} circle onClick={()=>{
                  this.examinePublicRelease(2);
                }}>
                  同意
                </AtButton>
              </View> : null
          }
        </View>
        {/*<View className='valueContent history'>*/}
        {/*  查看TA的历史记录*/}
        {/*  <AtIcon value='chevron-right' size='30' color='#767272'/>*/}
        {/*</View>*/}
      </View>
    )
  }
}

export default EgressDetails;
